C+
C NAME:
C	Time2Delta
C PURPOSE:
C	Get difference between times
C CATEGORY:
C	gen/for/lib
C CALLING SEQUENCE:
	subroutine Time2Delta(t,u,dt)
C INPUTS:
C	t(2)		integer		2-element standard time
C	u(2)		integer		2-element standard time
C OUTPUTS
C	dt(2)		integer		2-element standard time t-u
C CALLS:
C	Time2Standardize
C PROCEDURE:
C MODIFICATION HISTORY:
C	OCT-2003, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C-
	    integer	t (2)
	    integer	u (2)
	    integer	dt(2)

	dt(1) = t(1)-u(1)
	dt(2) = t(2)-u(2)

	call Time2Standardize(dt,dt)

	return
	end
